@@ -4,13 +4,16 @@ bag-of-word counts.
 """
 
 # bring model classes directly into package namespace, to save some typing
-from hdpmodel import HdpModel
-from ldamodel import LdaModel
-from lsimodel import LsiModel
-from tfidfmodel import TfidfModel
-from rpmodel import RpModel
-from logentropy_model import LogEntropyModel
-from word2vec import Word2Vec
+from .hdpmodel import HdpModel
+from .ldamodel import LdaModel
+from .ldamallet import LdaMallet
+from .lsimodel import LsiModel
+from .tfidfmodel import TfidfModel
+from .rpmodel import RpModel
+from .logentropy_model import LogEntropyModel
+from .word2vec import Word2Vec
+from .ldamulticore import LdaMulticore
+from .dtmmodel import DtmModel
 
 from gensim import interfaces, utils
 
