@@ -11,6 +11,8 @@
 """
 Latent Dirichlet Allocation (LDA) in Python.
 
+**Note**: For a faster implementation (parallelized for multicore machines), see the :class:`gensim.models.ldamulticore.LdaMulticore` class.
+
 This module allows both LDA model estimation from a training corpus and inference of topic
 distribution on new, unseen documents. The model can also be updated with new documents
 for online training.
@@ -32,7 +34,6 @@ The algorithm:
 
 
 import logging
-import itertools
 
 logger = logging.getLogger('gensim.models.ldamodel')
 
@@ -40,8 +41,7 @@ logger = logging.getLogger('gensim.models.ldamodel')
 import numpy # for arrays, array broadcasting etc.
 #numpy.seterr(divide='ignore') # ignore 0*log(0) errors
 
-from scipy.special import gammaln, digamma, psi # gamma function utils
-from scipy.special import gamma as gammafunc
+from scipy.special import gammaln, psi # gamma function utils
 from scipy.special import polygamma
 try:
     from scipy.maxentropy import logsumexp # log(sum(exp(x))) that tries to avoid overflow
@@ -198,11 +198,18 @@ class LdaModel(interfaces.TransformationABC):
         (theta) and topic-word (lambda) distributions. Both default to a symmetric
         1.0/num_topics prior.
 
-        `alpha` can be also set to an explicit array = prior of your choice. It also
+        `alpha` can be set to an explicit array = prior of your choice. It also
         support special values of 'asymmetric' and 'auto': the former uses a fixed
         normalized asymmetric 1.0/topicno prior, the latter learns an asymmetric
         prior directly from your data.
 
+        `eta` can be a scalar for a symmetric prior over topic/word
+        distributions, or a matrix of shape num_topics x num_words,
+        which can be used to impose asymmetric priors over the word
+        distribution on a per-topic basis. This may be useful if you
+        want to seed certain topics with particular words by boosting
+        the priors for those words.
+
         Turn on `distributed` to force distributed computing (see the `web tutorial <http://radimrehurek.com/gensim/distributed.html>`_
         on how to set up a cluster of machines for gensim).
 
@@ -335,6 +342,9 @@ class LdaModel(interfaces.TransformationABC):
         `(gamma, sstats)`. Otherwise, return `(gamma, None)`. `gamma` is of shape
         `len(chunk) x self.num_topics`.
 
+        Avoids computing the `phi` variational parameter directly using the
+        optimization presented in **Lee, Seung: Algorithms for non-negative matrix factorization, NIPS 2001**.
+
         """
         try:
             _ = len(chunk)
@@ -422,7 +432,7 @@ class LdaModel(interfaces.TransformationABC):
         Update parameters for the Dirichlet prior on the per-document
         topic weights `alpha` given the last `gammat`.
 
-        Uses Newton's method: http://www.stanford.edu/~jhuang11/research/dirichlet/dirichlet.pdf
+        Uses Newton's method, described in **Huang: Maximum Likelihood Estimation of Dirichlet Distribution Parameters.** (http://www.stanford.edu/~jhuang11/research/dirichlet/dirichlet.pdf)
 
         """
         N = float(len(gammat))
@@ -493,7 +503,7 @@ class LdaModel(interfaces.TransformationABC):
             gamma_threshold = self.gamma_threshold
 
         # rho is the "speed" of updating; TODO try other fncs
-        rho = lambda: pow(1.0 + self.num_updates, -decay)
+        rho = lambda: pow(1.0 + self.num_updates / self.chunksize, -decay)
 
         try:
             lencorpus = len(corpus)
@@ -601,12 +611,11 @@ class LdaModel(interfaces.TransformationABC):
         # the topics change through this update, to assess convergence
         diff = numpy.log(self.expElogbeta)
         self.state.blend(rho, other)
-        del other
         diff -= self.state.get_Elogbeta()
         self.sync_state()
         self.print_topics(15) # print out some debug info at the end of each EM iteration
         logger.info("topic diff=%f, rho=%f" % (numpy.mean(numpy.abs(diff)), rho))
-        self.num_updates += 1
+        self.num_updates += other.numdocs
 
 
     def bound(self, corpus, gamma=None, subsample_ratio=1.0):
@@ -646,7 +655,13 @@ class LdaModel(interfaces.TransformationABC):
         # E[log p(beta | eta) - log q (beta | lambda)]; assumes eta is a scalar
         score += numpy.sum((self.eta - _lambda) * Elogbeta)
         score += numpy.sum(gammaln(_lambda) - gammaln(self.eta))
-        score += numpy.sum(gammaln(self.eta * self.num_terms) - gammaln(numpy.sum(_lambda, 1)))
+
+        if numpy.ndim(self.eta) == 0:
+            sum_eta = self.eta * self.num_terms
+        else:
+            sum_eta = numpy.sum(self.eta, 1)
+
+        score += numpy.sum(gammaln(sum_eta) - gammaln(numpy.sum(_lambda, 1)))
         return score
 
 
